@@ -179,7 +179,11 @@ def handle_mqtt_messages(client, userdata, msg: mqtt.MQTTMessage):
             report_state()
     except SerialException:
         print("Serial Disconnected, Exiting. . .")
-        os._exit()
+        mqttclient.disconnect()
+        if os.name == 'posix':
+            os.kill(os.getpid(), signal.SIGINT)
+        else:
+            os._exit(0)
 mqttclient.on_message = handle_mqtt_messages
 
 report_state()
